@@ -3,7 +3,7 @@ package Sah::Schema::byte;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = ['uint8', {
     summary => 'Same as uint8',
@@ -29,7 +29,17 @@ Sah::Schema::byte - Same as uint8
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::byte (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::byte (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 0  # valid
+
+ 255  # valid
+
+ 256  # INVALID
 
 =head1 HOMEPAGE
 
