@@ -1,7 +1,7 @@
 package Sah::Schema::even;
 
 our $DATE = '2020-03-02'; # DATE
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = ['int', {
     summary => 'Even number',
@@ -28,7 +28,17 @@ Sah::Schema::even - Even number
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::even (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::even (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 0  # valid
+
+ 2  # valid
+
+ 1  # INVALID
 
 =head1 HOMEPAGE
 
