@@ -3,7 +3,7 @@ package Sah::Schema::int16;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = [int => {
     summary => '16-bit signed integer',
@@ -30,7 +30,15 @@ Sah::Schema::int16 - 16-bit signed integer
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::int16 (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::int16 (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 0  # valid
+
+ 65536  # INVALID
 
 =head1 HOMEPAGE
 
