@@ -1,7 +1,7 @@
 package Sah::Schema::natnum;
 
 our $DATE = '2020-03-02'; # DATE
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = ['posint', {
     summary => 'Same as posint',
@@ -34,7 +34,17 @@ Sah::Schema::natnum - Same as posint
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::natnum (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::natnum (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 1  # valid
+
+ 2  # valid
+
+ 0  # INVALID
 
 =head1 DESCRIPTION
 
