@@ -3,7 +3,7 @@ package Sah::Schema::negeven;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = ['negint', {
     summary => 'Negative even number',
@@ -29,7 +29,15 @@ Sah::Schema::negeven - Negative even number
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::negeven (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::negeven (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ -2  # valid
+
+ -1  # INVALID
 
 =head1 HOMEPAGE
 
