@@ -3,7 +3,7 @@ package Sah::Schema::nonnegint;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = [int => {
     summary   => 'Non-negative integer (0, 1, 2, ...) [DEPRECATED]',
@@ -37,7 +37,17 @@ Sah::Schema::nonnegint - Non-negative integer (0, 1, 2, ...) [DEPRECATED]
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::nonnegint (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::nonnegint (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 0  # valid
+
+ 1  # valid
+
+ -1  # INVALID
 
 =head1 DESCRIPTION
 
