@@ -3,7 +3,7 @@ package Sah::Schema::odd;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = ['int', {
     summary => 'Odd number',
@@ -31,7 +31,17 @@ Sah::Schema::odd - Odd number
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::odd (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::odd (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 1  # valid
+
+ -3  # valid
+
+ 2  # INVALID
 
 =head1 HOMEPAGE
 
