@@ -3,7 +3,7 @@ package Sah::Schema::poseven;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = ['posint', {
     summary => 'Positive even number',
@@ -30,7 +30,17 @@ Sah::Schema::poseven - Positive even number
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::poseven (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::poseven (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 2  # valid
+
+ 1  # INVALID
+
+ 0  # INVALID
 
 =head1 HOMEPAGE
 
