@@ -3,7 +3,7 @@ package Sah::Schema::posint;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Int'; # DIST
-our $VERSION = '0.072'; # VERSION
+our $VERSION = '0.073'; # VERSION
 
 our $schema = [int => {
     summary   => 'Positive integer (1, 2, ...)',
@@ -36,7 +36,17 @@ Sah::Schema::posint - Positive integer (1, 2, ...)
 
 =head1 VERSION
 
-This document describes version 0.072 of Sah::Schema::posint (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+This document describes version 0.073 of Sah::Schema::posint (from Perl distribution Sah-Schemas-Int), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ 1  # valid
+
+ 0  # INVALID
+
+ -1  # INVALID
 
 =head1 DESCRIPTION
 
